package com.yonge.cooleshow.admin.controller;

import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.microsvc.toolkit.common.response.paging.PageInfo;
import com.microsvc.toolkit.common.response.paging.QueryInfo;
import com.microsvc.toolkit.common.response.template.R;
import com.yonge.cooleshow.auth.api.client.SysUserFeignService;
import com.yonge.cooleshow.auth.api.entity.SysUser;
import com.yonge.cooleshow.biz.dal.service.AlbumCategoryService;
import com.yonge.cooleshow.biz.dal.wrapper.AlbumCategoryWrapper;
import com.yonge.toolset.base.exception.BizException;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

@Slf4j
@Validated
@RestController
@RequestMapping("/albumCategory")
@Api(tags = "机构专辑分类")
public class AlbumCategoryController {

    @Autowired
    private AlbumCategoryService albumCategoryService;

    @Autowired
    private SysUserFeignService sysUserFeignService;
    
    @ApiOperation(value = "查询分页", notes = "机构专辑分类- 传入 AlbumCategoryWrapper.AlbumCategoryQuery")
    @PostMapping("/page")
    public R<PageInfo<AlbumCategoryWrapper.AlbumCategory>> page(@RequestBody AlbumCategoryWrapper.AlbumCategoryQuery query) {
        
        IPage<AlbumCategoryWrapper.AlbumCategory> pages = albumCategoryService.selectPage(QueryInfo.getPage(query), query);
        
        return R.from(QueryInfo.pageInfo(pages));
	}
    
    @ApiOperation(value = "新增", notes = "机构专辑分类- 传入 AlbumCategoryWrapper.AlbumCategory")
	@PostMapping("/save")
	public R<JSONObject> add( @RequestBody @Validated AlbumCategoryWrapper.AddAlbumCategory albumCategory) {
        SysUser sysUser = sysUserFeignService.queryUserInfo();
        if (sysUser == null  || sysUser.getId() == null) {
            throw new BizException("用户信息获取失败");
        }
        albumCategory.setOperatorId(sysUser.getId());
        // 新增数据
        albumCategoryService.add(albumCategory);
        
        return R.defaultR();
	}

	@ApiOperation(value = "删除", notes = "机构专辑分类- 传入id")
	@PostMapping("/remove")
	public R<Boolean> remove(@RequestParam Long id) {
    
		return R.from(albumCategoryService.del(id));
	}
}