package com.yonge.cooleshow.biz.dal.service.impl;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.yonge.cooleshow.biz.dal.entity.MusicAlbum;
import com.yonge.cooleshow.biz.dal.service.MusicAlbumService;
import com.yonge.toolset.base.exception.BizException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.beans.BeanUtils;
import lombok.extern.slf4j.Slf4j;
import com.yonge.cooleshow.biz.dal.entity.AlbumCategory;
import com.yonge.cooleshow.biz.dal.wrapper.AlbumCategoryWrapper;
import com.yonge.cooleshow.biz.dal.mapper.AlbumCategoryMapper;
import com.yonge.cooleshow.biz.dal.service.AlbumCategoryService;
import org.springframework.transaction.annotation.Transactional;

/**
 * 机构专辑分类
 * 2024-12-19 16:57:26
 */
@Slf4j
@Service
public class AlbumCategoryServiceImpl extends ServiceImpl<AlbumCategoryMapper, AlbumCategory> implements AlbumCategoryService {

    @Autowired
    private MusicAlbumService musicAlbumService;

    
    /**
     * 分页查询
     * @param page IPage<AlbumCategory>
     * @param query AlbumCategoryWrapper.AlbumCategoryQuery
     * @return IPage<AlbumCategory>
     */
    @Override
    public IPage<AlbumCategoryWrapper.AlbumCategory> selectPage(IPage<AlbumCategoryWrapper.AlbumCategory> page, AlbumCategoryWrapper.AlbumCategoryQuery query) {
        
        return page.setRecords(baseMapper.selectPage(page, query));
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public void add(AlbumCategoryWrapper.AddAlbumCategory albumCategory) {
        MusicAlbum musicAlbum = musicAlbumService.getById(albumCategory.getAlbumId());
        if (musicAlbum == null) {
            throw new BizException("专辑不存在");
        }
        AlbumCategory entity = JSON.parseObject(albumCategory.jsonString(), AlbumCategory.class);
        entity.setUpdateBy(albumCategory.getOperatorId());
        if (entity.getId() == null) {
            entity.setCreateBy(albumCategory.getOperatorId());
        }
        this.saveOrUpdate(entity);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Boolean del(Long id) {
        return this.lambdaUpdate()
                .eq(AlbumCategory::getId, id)
                .set(AlbumCategory::getDelFlag, 1)
                .update();

    }

}