package com.yonge.cooleshow.biz.dal.wrapper;

import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.microsvc.toolkit.common.response.paging.QueryInfo;
import com.yonge.cooleshow.common.enums.ETenantAlbumCategoryType;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import java.util.Optional;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.apache.commons.lang3.StringUtils;

import javax.validation.constraints.NotNull;

/**
 * 机构专辑分类
 * 2024-12-19 16:57:26
 */
@ApiModel(value = "AlbumCategoryWrapper对象", description = "机构专辑分类查询对象")
public class AlbumCategoryWrapper {

    @Data
	@Builder
    @NoArgsConstructor
    @AllArgsConstructor
    @ApiModel(" AlbumCategoryQuery-机构专辑分类")
    public static class AlbumCategoryQuery implements QueryInfo {
    
    	@ApiModelProperty("当前页")
        private Integer page;
        
        @ApiModelProperty("分页行数")
        private Integer rows;

        @ApiModelProperty("关键字匹配")
		private String keyword;

        @ApiModelProperty("专辑ID")
        private Long albumId;

        @ApiModelProperty("专辑分类类别 类型 CATEGORY_TYPE 级别 CATEGORY_LEVEL")
        private String categoryType;

        public String getKeyword() {
            return Optional.ofNullable(keyword).filter(StringUtils::isNotBlank).orElse(null);
        }
        
        public String jsonString() {
            return JSON.toJSONString(this);
        }

        public static AlbumCategoryQuery from(String json) {
            return JSON.parseObject(json, AlbumCategoryQuery.class);
        }
    }  

    @Data
	@ApiModel(" AlbumCategory-机构专辑分类")
    public static class AlbumCategory {


        @ApiModelProperty("主键ID")
        private Long id;

        @ApiModelProperty("专辑ID")
        private Long albumId;

        @ApiModelProperty("专辑分类类别 类型 CATEGORY_TYPE 级别 CATEGORY_LEVEL")
        private String categoryType;

        @ApiModelProperty("专辑分类名称")
        private String name;

        @ApiModelProperty("排序")
        private Integer sort;


        public String jsonString() {
            return JSON.toJSONString(this);
        }

        public static AlbumCategory from(String json) {
            return JSON.parseObject(json, AlbumCategory.class);
        }
	}



    @Data
    @ApiModel(" AddAlbumCategory")
    public static class AddAlbumCategory {

        @ApiModelProperty("主键ID")
        private Long id;

        @ApiModelProperty("专辑ID")
        @NotNull(message = "专辑ID不能为空")
        private Long albumId;

        @ApiModelProperty("专辑分类类别 类型 CATEGORY_TYPE 级别 CATEGORY_LEVEL")
        @NotNull(message = "专辑分类类别不能为空")
        private ETenantAlbumCategoryType categoryType;

        @ApiModelProperty("专辑分类名称")
        @NotNull(message = "名称不能为空")
        private String name;

        @ApiModelProperty("排序")
        @NotNull(message = "排序不能为空")
        private Integer sort;


        @ApiModelProperty(value = "创建人",hidden = true)
        private Long operatorId;

        public String jsonString() {
            return JSON.toJSONString(this);
        }
    }
}